@@ -11,6 +11,7 @@ from yape.commands.pip import pip_install
 
 
 def check_delete_environment(config: YAPEConfig, force: bool = False):
+    """Helper: prompt to ask"""
     if force:
         return True
     yape_log.warn("You are about to delete the virtual environment @ " + config.venv_path)
@@ -20,6 +21,12 @@ def check_delete_environment(config: YAPEConfig, force: bool = False):
 
 
 def delete(config: YAPEConfig, force: bool = False):
+    """Delete the current virtual environment from the source directory.
+
+    Args:
+        config (YAPEConfig): The config
+        force (bool, optional): Do not ask before deleting. Defaults to False.
+    """
     if config.has_virtual_environment():
         if not check_delete_environment(config, force=force):
             yape_log.info("Aborted")
@@ -37,6 +44,15 @@ def init(
     merge_with_current: bool = False,
     add_requirement_files: bool = True,
 ):
+    """Initialize the virtual environment and the yape configuration in the source directory.
+
+    Args:
+        active_config (YAPEConfig): The current config.
+        config_filename (str, optional): The filename to use when writing the new config. Defaults to None.
+        python_version (str, optional): The python version to use. Defaults to None.
+        merge_with_current (bool, optional): If true, then merge with the existing config. Defaults to False.
+        add_requirement_files (bool, optional): If true, add requirement file imports. Defaults to True.
+    """
     # Checking configuration
     to_merge: List[YAPEConfig] = []
     to_merge.append(
@@ -99,6 +115,14 @@ def install(
     reset: bool = False,
     force: bool = False,
 ):
+    """Install the yape config in the virtual environment.
+    Will create the environment if it dose not exist.
+
+    Args:
+        config (YAPEConfig): The config
+        reset (bool, optional): If true, resets the virtual environment. Defaults to False.
+        force (bool, optional): If true, dose not ask before resetting the virtual environment. Defaults to False.
+    """
     if reset and config.has_virtual_environment():
         delete(config, force=force)
         yape_log.info("Deleted current virtual env")
